@@ -13,30 +13,32 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
 from oslo_log import log as logging
 from paste import deploy
 
+import designate.conf
 from designate import exceptions
 from designate import service
 from designate import utils
 
+
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
 class Service(service.WSGIService):
     def __init__(self):
-        super(Service, self).__init__(
+        super().__init__(
             self.wsgi_application,
             self.service_name,
-            cfg.CONF['service:api'].listen,
+            CONF['service:api'].listen,
         )
 
     def start(self):
-        super(Service, self).start()
+        super().start()
 
     def stop(self, graceful=True):
-        super(Service, self).stop(graceful)
+        super().stop(graceful)
 
     @property
     def service_name(self):
@@ -44,7 +46,7 @@ class Service(service.WSGIService):
 
     @property
     def wsgi_application(self):
-        api_paste_config = cfg.CONF['service:api'].api_paste_config
+        api_paste_config = CONF['service:api'].api_paste_config
         config_paths = utils.find_config(api_paste_config)
 
         if not config_paths:
