@@ -24,6 +24,8 @@
 # ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
 import inspect
 
 import pecan
@@ -32,8 +34,6 @@ import pecan.routing
 
 from designate import exceptions
 from designate.central import rpcapi as central_rpcapi
-from designate.pool_manager import rpcapi as pool_mgr_rpcapi
-from designate.i18n import _
 
 
 class RestController(pecan.rest.RestController):
@@ -51,10 +51,6 @@ class RestController(pecan.rest.RestController):
     def central_api(self):
         return central_rpcapi.CentralAPI.get_instance()
 
-    @property
-    def pool_mgr_api(self):
-        return pool_mgr_rpcapi.PoolManagerAPI.get_instance()
-
     def _apply_filter_params(self, params, accepted_filters, criterion):
         invalid = []
         for k in params:
@@ -68,10 +64,10 @@ class RestController(pecan.rest.RestController):
         else:
             return criterion
 
-    def _handle_post(self, method, remainder):
-        '''
+    def _handle_post(self, method, remainder, request=None):
+        """
         Routes ``POST`` actions to the appropriate controller.
-        '''
+        """
         # route to a post_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('post_all', 'post')
@@ -81,7 +77,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular post_one/post requests
         controller = self._find_controller('post_one', 'post')
@@ -90,10 +87,10 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_patch(self, method, remainder):
-        '''
+    def _handle_patch(self, method, remainder, request=None):
+        """
         Routes ``PATCH`` actions to the appropriate controller.
-        '''
+        """
         # route to a patch_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('patch_all', 'patch')
@@ -103,7 +100,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular patch_one/patch requests
         controller = self._find_controller('patch_one', 'patch')
@@ -112,10 +110,10 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_put(self, method, remainder):
-        '''
+    def _handle_put(self, method, remainder, request=None):
+        """
         Routes ``PUT`` actions to the appropriate controller.
-        '''
+        """
         # route to a put_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('put_all', 'put')
@@ -125,7 +123,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular put_one/put requests
         controller = self._find_controller('put_one', 'put')
@@ -134,10 +133,10 @@ class RestController(pecan.rest.RestController):
 
         pecan.abort(405)
 
-    def _handle_delete(self, method, remainder):
-        '''
+    def _handle_delete(self, method, remainder, request=None):
+        """
         Routes ``DELETE`` actions to the appropriate controller.
-        '''
+        """
         # route to a delete_all or get if no additional parts are available
         if not remainder or remainder == ['']:
             controller = self._find_controller('delete_all', 'delete')
@@ -147,7 +146,8 @@ class RestController(pecan.rest.RestController):
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
-            return pecan.routing.lookup_controller(controller, remainder[1:])
+            return pecan.routing.lookup_controller(controller, remainder[1:],
+                                                   request=request)
 
         # finally, check for the regular delete_one/delete requests
         controller = self._find_controller('delete_one', 'delete')
