@@ -21,14 +21,12 @@ from oslo_reports import guru_meditation_report as gmr
 from designate.central import service as central_service
 import designate.conf
 from designate import heartbeat_emitter
-from designate import hookpoints
 from designate import service
 from designate import utils
 from designate import version
 
 
 CONF = designate.conf.CONF
-CONF.import_opt('workers', 'designate.central', group='service:central')
 
 
 def main():
@@ -36,8 +34,6 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
-
     server = central_service.Service()
     heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name,
                                                         rpc_api=server)
