@@ -15,7 +15,9 @@
 # under the License.
 #
 # Copied: designate
+
 import sys
+import traceback
 
 import eventlet
 from oslo_config import cfg
@@ -24,7 +26,6 @@ from oslo_reports import guru_meditation_report as gmr
 from stevedore.extension import ExtensionManager
 
 import designate.conf
-from designate import hookpoints
 from designate import utils
 from designate import version
 
@@ -52,7 +53,7 @@ def methods_of(obj):
 
 def get_available_commands():
     em = ExtensionManager('designate.manage')
-    return dict([(e.name, e.plugin) for e in em.extensions])
+    return {e.name: e.plugin for e in em.extensions}
 
 
 def add_command_parsers(subparsers):
@@ -63,8 +64,9 @@ def add_command_parsers(subparsers):
         parser.set_defaults(command_object=command_object)
 
         category_subparsers = parser.add_subparsers(dest='action')
+        category_subparsers.required = True
 
-        for (action, action_fn) in methods_of(command_object):
+        for action, action_fn in methods_of(command_object):
             action = getattr(action_fn, '_cmd_name', action)
             parser = category_subparsers.add_parser(action)
 
@@ -76,8 +78,8 @@ def add_command_parsers(subparsers):
             parser.set_defaults(action_kwargs=action_kwargs)
 
 
-category_opt = cfg.SubCommandOpt('category', title="Commands",
-                                 help="Available Commands",
+category_opt = cfg.SubCommandOpt('category', title='Commands',
+                                 help='Available Commands',
                                  handler=add_command_parsers)
 
 
@@ -109,15 +111,15 @@ def fetch_func_args(func):
 
 def main():
     CONF.register_cli_opt(category_opt)
-
     utils.read_config('designate', sys.argv)
     logging.setup(CONF, 'designate')
 
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
-
-    fn = CONF.category.action_fn
-
-    fn_args = fetch_func_args(fn)
-    fn(*fn_args)
+    try:
+        fn = CONF.category.action_fn
+        fn_args = fetch_func_args(fn)
+        fn(*fn_args)
+    except Exception:
+        print('An error has occurred:\n%s' % traceback.format_exc())
+        return 255
