@@ -13,23 +13,15 @@
 #    under the License.
 from oslo_config import cfg
 
-from designate.conf import agent
 from designate.conf import api
 from designate.conf import base  # noqa
-from designate.conf import bind9
 from designate.conf import central
 from designate.conf import coordination
-from designate.conf import denominator
-from designate.conf import djbdns
 from designate.conf import dynect
-from designate.conf import gdnsd
 from designate.conf import heartbeat_emitter
 from designate.conf import infoblox
 from designate.conf import keystone
-from designate.conf import knot2
 from designate.conf import mdns
-from designate.conf import metrics
-from designate.conf import msdns
 from designate.conf import network_api
 from designate.conf import producer
 from designate.conf import proxy
@@ -40,22 +32,14 @@ from designate.conf import worker
 CONF = cfg.CONF
 
 base.register_opts(CONF)
-agent.register_opts(CONF)
 api.register_opts(CONF)
-bind9.register_opts(CONF)
 central.register_opts(CONF)
 coordination.register_opts(CONF)
-denominator.register_opts(CONF)
-djbdns.register_opts(CONF)
 dynect.register_opts(CONF)
-gdnsd.register_opts(CONF)
 heartbeat_emitter.register_opts(CONF)
 infoblox.register_opts(CONF)
 keystone.register_opts(CONF)
-knot2.register_opts(CONF)
 mdns.register_opts(CONF)
-metrics.register_opts(CONF)
-msdns.register_opts(CONF)
 network_api.register_opts(CONF)
 producer.register_opts(CONF)
 proxy.register_opts(CONF)
