@@ -13,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from designate.context import DesignateContext
+from designate import context
 
 
 # Decorators for actions
@@ -34,7 +34,13 @@ def name(name):
     return _decorator
 
 
-class Commands(object):
+class Commands:
     def __init__(self):
-        self.context = DesignateContext.get_admin_context(
-            request_id='designate-manage')
+        self.context = context.DesignateContext.get_admin_context(
+            request_id='designate-manage'
+        )
+        self.output_message = ['']
+
+    def _print_result(self):
+        for message in self.output_message:
+            print(message)
