@@ -13,33 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from designate.objects import base
+from designate.objects import fields
 
 
+@base.DesignateRegistry.register
 class PoolNameserver(base.DictObjectMixin, base.PersistentObjectMixin,
                      base.DesignateObject):
-    FIELDS = {
-        'pool_id': {
-            'schema': {
-                'type': 'string',
-                'description': 'Pool identifier',
-                'format': 'uuid',
-            },
-        },
-        'host': {
-            'schema': {
-                'type': 'string',
-                'format': 'ip-or-host',
-                'required': True,
-            },
-        },
-        'port': {
-            'schema': {
-                'type': 'integer',
-                'minimum': 1,
-                'maximum': 65535,
-                'required': True,
-            },
-        }
+    fields = {
+        'pool_id': fields.UUIDFields(nullable=True),
+        'host': fields.IPOrHost(),
+        'port': fields.IntegerFields(minimum=1, maximum=65535),
     }
 
     STRING_KEYS = [
@@ -47,5 +30,9 @@ class PoolNameserver(base.DictObjectMixin, base.PersistentObjectMixin,
     ]
 
 
+@base.DesignateRegistry.register
 class PoolNameserverList(base.ListObjectMixin, base.DesignateObject):
     LIST_ITEM_TYPE = PoolNameserver
+    fields = {
+        'objects': fields.ListOfObjectsField('PoolNameserver'),
+    }
