@@ -13,19 +13,19 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
 from designate.central import rpcapi
+import designate.conf
 from designate import coordination
 from designate import exceptions
 from designate.producer import tasks
 from designate import service
 
 
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 
 NS = 'designate.periodic_tasks'
 
@@ -41,9 +41,9 @@ class Service(service.RPCService):
         self._storage = None
         self._quota = None
 
-        super(Service, self).__init__(
-            self.service_name, cfg.CONF['service:producer'].topic,
-            threads=cfg.CONF['service:producer'].threads,
+        super().__init__(
+            self.service_name, CONF['service:producer'].topic,
+            threads=CONF['service:producer'].threads,
         )
 
         self.coordination = coordination.Coordination(
@@ -59,7 +59,7 @@ class Service(service.RPCService):
         return rpcapi.CentralAPI.get_instance()
 
     def start(self):
-        super(Service, self).start()
+        super().start()
         self.coordination.start()
 
         self._partitioner = coordination.Partitioner(
@@ -91,7 +91,7 @@ class Service(service.RPCService):
             self.tg.add_timer(interval, task)
 
     def stop(self, graceful=True):
-        super(Service, self).stop(graceful)
+        super().stop(graceful)
         self.coordination.stop()
 
     def _rebalance(self, my_partitions, members, event):
