@@ -30,10 +30,10 @@ from oslo_service import sslutils
 from oslo_service import wsgi
 from oslo_utils import netutils
 
+from designate.common.decorators import rpc as rpc_decorator
 from designate.common import profiler
 import designate.conf
 from designate.i18n import _
-from designate.metrics import metrics
 from designate import policy
 from designate import rpc
 from designate import utils
@@ -46,7 +46,7 @@ LOG = logging.getLogger(__name__)
 class Service(service.Service):
     def __init__(self, name, threads=None):
         threads = threads or 1000
-        super(Service, self).__init__(threads)
+        super().__init__(threads)
         self.name = name
         self.host = CONF.host
 
@@ -64,29 +64,27 @@ class Service(service.Service):
                      'name': self.name,
                      'version': version.version_info.version_string()
                  })
-        super(Service, self).start()
+        super().start()
 
     def stop(self, graceful=True):
         LOG.info('Stopping %(name)s service', {'name': self.name})
-        super(Service, self).stop(graceful)
+        super().stop(graceful)
 
 
 class RPCService(Service):
     def __init__(self, name, rpc_topic, threads=None):
-        super(RPCService, self).__init__(name, threads)
+        super().__init__(name, threads)
         LOG.debug("Creating RPC Server on topic '%s' for %s",
                   rpc_topic, self.name)
 
         self.endpoints = [self]
+        self.exception_thread_local = rpc_decorator.ExceptionThreadLocal()
         self.notifier = None
         self.rpc_server = None
         self.rpc_topic = rpc_topic
 
-    def override_endpoints(self, endpoints):
-        self.endpoints = endpoints
-
     def start(self):
-        super(RPCService, self).start()
+        super().start()
         target = messaging.Target(topic=self.rpc_topic, server=self.host)
         self.rpc_server = rpc.get_server(target, self.endpoints)
         self.rpc_server.start()
@@ -95,15 +93,15 @@ class RPCService(Service):
     def stop(self, graceful=True):
         if self.rpc_server:
             self.rpc_server.stop()
-        super(RPCService, self).stop(graceful)
+        super().stop(graceful)
 
     def wait(self):
-        super(RPCService, self).wait()
+        super().wait()
 
 
 class WSGIService(Service):
     def __init__(self, app, name, listen, max_url_len=None):
-        super(WSGIService, self).__init__(name)
+        super().__init__(name)
         self.app = app
         self.name = name
 
@@ -127,20 +125,20 @@ class WSGIService(Service):
     def start(self):
         for server in self.servers:
             server.start()
-        super(WSGIService, self).start()
+        super().start()
 
     def stop(self, graceful=True):
         for server in self.servers:
             server.stop()
-        super(WSGIService, self).stop(graceful)
+        super().stop(graceful)
 
     def wait(self):
         for server in self.servers:
             server.wait()
-        super(WSGIService, self).wait()
+        super().wait()
 
 
-class DNSService(object):
+class DNSService:
     _TCP_RECV_MAX_SIZE = 65535
 
     def __init__(self, app, tg, listen, tcp_backlog, tcp_recv_timeout):
@@ -150,7 +148,6 @@ class DNSService(object):
         self.tcp_backlog = tcp_backlog
         self.tcp_recv_timeout = tcp_recv_timeout
         self.listen = listen
-        metrics.init()
 
         # Eventet will complain loudly about our use of multiple greentheads
         # reading/writing to the UDP socket at once. Disable this warning.
@@ -172,10 +169,11 @@ class DNSService(object):
 
     def _start(self, host, port):
         sock_tcp = utils.bind_tcp(
-            host, port, self.tcp_backlog)
-
+            host, port, self.tcp_backlog
+        )
         sock_udp = utils.bind_udp(
-            host, port)
+            host, port
+        )
 
         self._dns_socks_tcp.append(sock_tcp)
         self._dns_socks_udp.append(sock_udp)
@@ -197,6 +195,7 @@ class DNSService(object):
 
         client = None
         while self._running.is_set():
+            addr = None
             try:
                 # handle a new TCP connection
                 client, addr = sock_tcp.accept()
@@ -204,11 +203,21 @@ class DNSService(object):
                 if self.tcp_recv_timeout:
                     client.settimeout(self.tcp_recv_timeout)
 
-                LOG.debug('Handling TCP Request from: %(host)s:%(port)d',
-                          {'host': addr[0], 'port': addr[1]})
+                LOG.debug(
+                    'Handling TCP Request from: %(host)s:%(port)d',
+                    {
+                        'host': addr[0],
+                        'port': addr[1]
+                    }
+                )
                 if len(addr) == 4:
-                    LOG.debug('Flow info: %(host)s scope: %(port)d',
-                              {'host': addr[2], 'port': addr[3]})
+                    LOG.debug(
+                        'Flow info: %(host)s scope: %(port)d',
+                        {
+                            'host': addr[2],
+                            'port': addr[3]
+                        }
+                    )
 
                 # Dispatch a thread to handle the connection
                 self.tg.add_thread(self._dns_handle_tcp_conn, addr, client)
@@ -218,18 +227,31 @@ class DNSService(object):
             # ensure no exceptions are generated from within.
             except socket.timeout:
                 pass
-            except socket.error as e:
+            except OSError as e:
                 if client:
                     client.close()
                 errname = errno.errorcode[e.args[0]]
-                LOG.warning('Socket error %(err)s from: %(host)s:%(port)d',
-                            {'host': addr[0], 'port': addr[1], 'err': errname})
+                addr = addr or (None, 0)
+                LOG.warning(
+                    'Socket error %(err)s from: %(host)s:%(port)d',
+                    {
+                        'host': addr[0],
+                        'port': addr[1],
+                        'err': errname
+                    }
+                )
             except Exception:
                 if client:
                     client.close()
-                LOG.exception('Unknown exception handling TCP request from: '
-                              '%(host)s:%(port)d',
-                              {'host': addr[0], 'port': addr[1]})
+                addr = addr or (None, 0)
+                LOG.exception(
+                    'Unknown exception handling TCP request from: '
+                    '%(host)s:%(port)d',
+                    {
+                        'host': addr[0],
+                        'port': addr[1]
+                    }
+                )
 
     def _dns_handle_tcp_conn(self, addr, client):
         """
@@ -243,7 +265,7 @@ class DNSService(object):
                      (IPv6 addr, Port, Flow info, Scope ID)
         :type addr: tuple
         :param client: Client socket
-        :type client: socket
+        :type client: socket.socket
         :raises: None
         """
         host, port = addr[:2]
@@ -272,8 +294,7 @@ class DNSService(object):
                 query = buf
 
                 # Call into the DNS Application itself with payload and addr
-                for response in self.app(
-                        {'payload': query, 'addr': addr}):
+                for response in self.app({'payload': query, 'addr': addr}):
 
                     # Send back a response only if present
                     if response is None:
@@ -285,62 +306,100 @@ class DNSService(object):
                     client.sendall(tcp_response)
 
         except socket.timeout:
-            LOG.info('TCP Timeout from: %(host)s:%(port)d',
-                     {'host': host, 'port': port})
-        except socket.error as e:
+            LOG.info(
+                'TCP Timeout from: %(host)s:%(port)d',
+                {
+                    'host': host,
+                    'port': port
+                }
+            )
+        except OSError as e:
             errname = errno.errorcode[e.args[0]]
-            LOG.warning('Socket error %(err)s from: %(host)s:%(port)d',
-                        {'host': host, 'port': port, 'err': errname})
-
+            LOG.warning(
+                'Socket error %(err)s from: %(host)s:%(port)d',
+                {
+                    'host': host,
+                    'port': port,
+                    'err': errname
+                }
+            )
         except struct.error:
-            LOG.warning('Invalid packet from: %(host)s:%(port)d',
-                        {'host': host, 'port': port})
-
+            LOG.warning(
+                'Invalid packet from: %(host)s:%(port)d',
+                {
+                    'host': host,
+                    'port': port
+                }
+            )
         except Exception:
-            LOG.exception('Unknown exception handling TCP request from: '
-                          "%(host)s:%(port)d", {'host': host, 'port': port})
+            LOG.exception(
+                'Unknown exception handling TCP request from: '
+                '%(host)s:%(port)d',
+                {
+                    'host': host,
+                    'port': port
+                }
+            )
         finally:
-            if client:
-                client.close()
+            client.close()
 
     def _dns_handle_udp(self, sock_udp):
         """Handle a DNS Query over UDP in a dedicated thread
 
         :param sock_udp: UDP socket
-        :type sock_udp: socket
+        :type sock_udp: socket.socket
         :raises: None
         """
         LOG.info('_handle_udp thread started')
 
         while self._running.is_set():
+            addr = None
             try:
                 # TODO(kiall): Determine the appropriate default value for
                 #              UDP recvfrom.
                 payload, addr = sock_udp.recvfrom(8192)
 
-                LOG.debug('Handling UDP Request from: %(host)s:%(port)d',
-                          {'host': addr[0], 'port': addr[1]})
+                LOG.debug(
+                    'Handling UDP Request from: %(host)s:%(port)d',
+                    {
+                        'host': addr[0],
+                        'port': addr[1]
+                    }
+                )
 
                 # Dispatch a thread to handle the query
                 self.tg.add_thread(self._dns_handle_udp_query, sock_udp, addr,
                                    payload)
             except socket.timeout:
                 pass
-            except socket.error as e:
+            except OSError as e:
                 errname = errno.errorcode[e.args[0]]
-                LOG.warning('Socket error %(err)s from: %(host)s:%(port)d',
-                            {'host': addr[0], 'port': addr[1], 'err': errname})
+                addr = addr or (None, 0)
+                LOG.warning(
+                    'Socket error %(err)s from: %(host)s:%(port)d',
+                    {
+                        'host': addr[0],
+                        'port': addr[1],
+                        'err': errname
+                    }
+                )
             except Exception:
-                LOG.exception('Unknown exception handling UDP request from: '
-                              '%(host)s:%(port)d',
-                              {'host': addr[0], 'port': addr[1]})
+                addr = addr or (None, 0)
+                LOG.exception(
+                    'Unknown exception handling UDP request from: '
+                    '%(host)s:%(port)d',
+                    {
+                        'host': addr[0],
+                        'port': addr[1]
+                    }
+                )
 
     def _dns_handle_udp_query(self, sock, addr, payload):
         """
         Handle a DNS Query over UDP
 
         :param sock: UDP socket
-        :type sock: socket
+        :type sock: socket.socket
         :param addr: Tuple of the client's (IP, Port)
         :type addr: tuple
         :param payload: Raw DNS query payload
@@ -349,17 +408,18 @@ class DNSService(object):
         """
         try:
             # Call into the DNS Application itself with the payload and addr
-            for response in self.app(
-                    {'payload': payload, 'addr': addr}):
-
-                # Send back a response only if present
+            for response in self.app({'payload': payload, 'addr': addr}):
                 if response is not None:
                     sock.sendto(response, addr)
-
         except Exception:
-            LOG.exception('Unhandled exception while processing request from '
-                          "%(host)s:%(port)d",
-                          {'host': addr[0], 'port': addr[1]})
+            LOG.exception(
+                'Unhandled exception while processing request from '
+                '%(host)s:%(port)d',
+                {
+                    'host': addr[0],
+                    'port': addr[1]
+                }
+            )
 
 
 _launcher = None
