@@ -14,6 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+
 from unittest import mock
 
 from designateclient import exceptions
@@ -24,15 +25,16 @@ import oslotest.base
 from designate.backend import impl_designate
 from designate import context
 from designate import objects
-from designate.tests import fixtures
+from designate.tests import base_fixtures
+
 
 LOG = logging.getLogger(__name__)
 
 
 class DesignateBackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(DesignateBackendTestCase, self).setUp()
-        self.stdlog = fixtures.StandardLogging()
+        super().setUp()
+        self.stdlog = base_fixtures.StandardLogging()
         self.useFixture(self.stdlog)
 
         self.admin_context = mock.Mock()
