@@ -13,39 +13,40 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+
 from unittest import mock
 
 import dns
-from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
-from oslo_messaging import conffixture as messaging_fixture
 import oslotest.base
 
+import designate.conf
 from designate import exceptions
 from designate.mdns import handler
 from designate import objects
-from designate.tests import fixtures
+from designate import rpc
+from designate.tests import base_fixtures
 from designate.worker import rpcapi as worker_rpcapi
 
-CONF = cfg.CONF
+
+CONF = designate.conf.CONF
 
 
 class MdnsHandleTest(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(MdnsHandleTest, self).setUp()
-        self.stdlog = fixtures.StandardLogging()
+        super().setUp()
+        self.stdlog = base_fixtures.StandardLogging()
         self.useFixture(self.stdlog)
         self.useFixture(cfg_fixture.Config(CONF))
+
         self.context = mock.Mock()
         self.storage = mock.Mock()
         self.tg = mock.Mock()
-        self.handler = handler.RequestHandler(self.storage, self.tg)
-        self.messaging_conf = messaging_fixture.ConfFixture(CONF)
-        self.messaging_conf.transport_url = 'fake:/'
-        self.messaging_conf.response_timeout = 5
-        self.useFixture(self.messaging_conf)
-        self.useFixture(fixtures.RPCFixture(CONF))
 
+        self.handler = handler.RequestHandler(self.storage, self.tg)
+
+    @mock.patch.object(rpc, 'get_client', mock.Mock())
     def test_worker_api(self):
         self.assertIsNone(self.handler._worker_api)
         self.assertIsInstance(self.handler.worker_api,
@@ -54,6 +55,7 @@ class MdnsHandleTest(oslotest.base.BaseTestCase):
         self.assertIsInstance(self.handler.worker_api,
                               worker_rpcapi.WorkerAPI)
 
+    @mock.patch.object(rpc, 'get_client', mock.Mock())
     @mock.patch.object(dns.resolver.Resolver, 'resolve')
     def test_notify(self, mock_query):
         self.storage.find_zone.return_value = objects.Zone(
@@ -143,14 +145,14 @@ class MdnsHandleTest(oslotest.base.BaseTestCase):
         request = dns.message.make_query(
             'www.example.org.', dns.rdatatype.SOA
         )
-        request.environ = dict(addr=['127.0.0.1', 53], context=self.context)
+        request.environ = dict(addr=['203.0.113.1', 53], context=self.context)
 
         response = self.handler._handle_notify(request)
 
         self.assertEqual(dns.rcode.REFUSED, tuple(response)[0].rcode())
 
         self.assertIn(
-            'NOTIFY for None from non-master server 127.0.0.1, refusing.',
+            'NOTIFY for None from non-master server 203.0.113.1, refusing.',
             self.stdlog.logger.output
         )
 
@@ -216,10 +218,39 @@ class MdnsHandleTest(oslotest.base.BaseTestCase):
             65300, self.handler._get_max_message_size(had_tsig=True)
         )
 
+    def test_zone_criterion_from_request_unknown_scope(self):
+        mock_tsigkey = mock.Mock()
+        mock_tsigkey.scope = 'UNKNOWN'
+
+        request = dns.message.make_query(
+            'www.example.org.', dns.rdatatype.AXFR
+        )
+        request.environ = dict(context=self.context, tsigkey=mock_tsigkey)
+
+        self.assertRaisesRegex(
+            NotImplementedError,
+            'Support for UNKNOWN scoped TSIG Keys is not implemented',
+            self.handler._zone_criterion_from_request, request
+        )
+
+    def test_zone_criterion_from_request_enforce_tsig(self):
+        CONF.set_override('query_enforce_tsig', True, 'service:mdns')
+
+        request = dns.message.make_query(
+            'www.example.org.', dns.rdatatype.AXFR
+        )
+        request.environ = dict(context=self.context, tsigkey=None)
+
+        self.assertRaisesRegex(
+            exceptions.Forbidden,
+            'Request is not TSIG signed',
+            self.handler._zone_criterion_from_request, request
+        )
+
 
 class TestRequestHandlerCall(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestRequestHandlerCall, self).setUp()
+        super().setUp()
         self.handler = handler.RequestHandler(mock.Mock(), mock.Mock())
 
         # Use a simple handlers that doesn't require a real request
@@ -329,7 +360,7 @@ class TestRequestHandlerCall(oslotest.base.BaseTestCase):
 
 class HandleRecordQueryTest(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(HandleRecordQueryTest, self).setUp()
+        super().setUp()
         self.context = mock.Mock()
         self.storage = mock.Mock()
         self.handler = handler.RequestHandler(self.storage, mock.Mock())
