@@ -15,13 +15,13 @@
 # under the License.
 import time
 
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
 from designate import backend
 from designate.central import rpcapi as central_api
 from designate.common.decorators import rpc
+import designate.conf
 from designate.context import DesignateContext
 from designate import exceptions
 from designate import service
@@ -31,10 +31,10 @@ from designate.worker.tasks import zone as zonetasks
 
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 
 
-class AlsoNotifyTask(object):
+class AlsoNotifyTask:
     """
     Placeholder to define options for also_notify targets
     """
@@ -53,9 +53,9 @@ class Service(service.RPCService):
         self._executor = None
         self._pools_map = None
 
-        super(Service, self).__init__(
-            self.service_name, cfg.CONF['service:worker'].topic,
-            threads=cfg.CONF['service:worker'].threads,
+        super().__init__(
+            self.service_name, CONF['service:worker'].topic,
+            threads=CONF['service:worker'].threads,
         )
 
     @property
@@ -134,11 +134,11 @@ class Service(service.RPCService):
         return self.pools_map[pool_id]
 
     def start(self):
-        super(Service, self).start()
+        super().start()
         LOG.info('Started worker')
 
     def stop(self, graceful=True):
-        super(Service, self).stop(graceful)
+        super().stop(graceful)
 
     def _do_zone_action(self, context, zone, zone_params=None):
         pool = self.get_pool(zone.pool_id)
