@@ -15,22 +15,22 @@
 # under the License.
 from collections import namedtuple
 import errno
-import socket
 import time
 
 import dns
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import timeutils
 
 from designate.common import constants
+import designate.conf
 from designate import dnsutils
 from designate import exceptions
 from designate import objects
 from designate.worker.tasks import base
 
+
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 
 ######################
 # CRUD Zone Operations
@@ -45,7 +45,7 @@ class ZoneActionOnTarget(base.Task):
     """
 
     def __init__(self, executor, context, zone, target, zone_params):
-        super(ZoneActionOnTarget, self).__init__(executor)
+        super().__init__(executor)
         self.zone = zone
         self.action = zone.action
         self.target = target
@@ -65,17 +65,41 @@ class ZoneActionOnTarget(base.Task):
             }
         )
 
+        # Check whether a catalog zone exists for this pool
+        catalog_zone = None
+        pool = self.storage.find_pool(
+            self.context, criterion={'id': self.zone.pool_id})
+        try:
+            catalog_zone = self.storage.get_catalog_zone(
+                self.context, pool)
+        except exceptions.ZoneNotFound:
+            pass
+
         for retry in range(0, self.max_retries):
             try:
-                if self.action == 'CREATE':
-                    self.target.backend.create_zone(self.context, self.zone)
-                    SendNotify(self.executor, self.zone, self.target)()
-                elif self.action == 'DELETE':
-                    self.target.backend.delete_zone(self.context, self.zone,
-                                                    self.zone_params)
+                if catalog_zone is None:
+                    if self.action == 'CREATE':
+                        self.target.backend.create_zone(
+                            self.context, self.zone)
+                        SendNotify(self.executor, self.zone, self.target)()
+                    elif self.action == 'DELETE' and catalog_zone is None:
+                        self.target.backend.delete_zone(
+                            self.context, self.zone, self.zone_params)
+                    else:
+                        self.target.backend.update_zone(
+                            self.context, self.zone)
+                        SendNotify(self.executor, self.zone, self.target)()
                 else:
-                    self.target.backend.update_zone(self.context, self.zone)
-                    SendNotify(self.executor, self.zone, self.target)()
+                    if (
+                        self.action == 'CREATE' or self.action == 'DELETE' or
+                        self.zone.type == constants.ZONE_CATALOG
+                    ):
+                        # Member zone created or deleted, or catalog zone
+                        # itself modified, NOTIFY via catalog
+                        SendNotify(self.executor, catalog_zone, self.target)()
+                    else:
+                        # Member zone updated
+                        SendNotify(self.executor, self.zone, self.target)()
 
                 LOG.debug(
                     'Successfully performed %(action)s for '
@@ -118,7 +142,7 @@ class SendNotify(base.Task):
     """
 
     def __init__(self, executor, zone, target):
-        super(SendNotify, self).__init__(executor)
+        super().__init__(executor)
         self.zone = zone
         self.target = target
 
@@ -162,7 +186,7 @@ class ZoneXfr(base.Task):
     """
 
     def __init__(self, executor, context, zone, servers=None):
-        super(ZoneXfr, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.zone = zone
         self.servers = servers
@@ -201,7 +225,7 @@ class ZoneActor(base.Task):
     """
 
     def __init__(self, executor, context, pool, zone, zone_params=None):
-        super(ZoneActor, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
@@ -259,7 +283,7 @@ class ZoneAction(base.Task):
 
     def __init__(self, executor, context, pool, zone, action,
                  zone_params=None):
-        super(ZoneAction, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
@@ -376,7 +400,7 @@ class PollForZone(base.Task):
     """
 
     def __init__(self, executor, zone, ns):
-        super(PollForZone, self).__init__(executor)
+        super().__init__(executor)
         self.zone = zone
         self.ns = ns
 
@@ -458,7 +482,7 @@ class ZonePoller(base.Task):
     """
 
     def __init__(self, executor, context, pool, zone):
-        super(ZonePoller, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
@@ -606,7 +630,7 @@ class GetZoneSerial(base.Task):
     Get zone serial number from a resolver using retries.
     """
     def __init__(self, executor, context, zone, host, port):
-        super(GetZoneSerial, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.zone = zone
         self.host = host
@@ -693,7 +717,7 @@ class GetZoneSerial(base.Task):
             return dnsutils.soa_query(
                 zone_name, host, port, timeout=self.serial_timeout
             )
-        except socket.error as e:
+        except OSError as e:
             if e.errno != errno.EAGAIN:
                 raise
             LOG.info(
@@ -745,7 +769,7 @@ class UpdateStatus(base.Task):
     """
 
     def __init__(self, executor, context, zone):
-        super(UpdateStatus, self).__init__(executor)
+        super().__init__(executor)
         self.zone = zone
         self.context = context
 
@@ -783,14 +807,14 @@ class RecoverShard(base.Task):
     """
 
     def __init__(self, executor, context, begin, end):
-        super(RecoverShard, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.begin_shard = begin
         self.end_shard = end
 
     def _get_zones(self):
         criterion = {
-            'shard': "BETWEEN %s,%s" % (self.begin_shard, self.end_shard),
+            'shard': f'BETWEEN {self.begin_shard},{self.end_shard}',
             'status': 'ERROR'
         }
         error_zones = self.storage.find_zones(self.context, criterion)
@@ -799,9 +823,9 @@ class RecoverShard(base.Task):
         # status for longer than they should
         # Generate the current serial, will provide a UTC Unix TS.
         stale_criterion = {
-            'shard': "BETWEEN %s,%s" % (self.begin_shard, self.end_shard),
+            'shard': f'BETWEEN {self.begin_shard},{self.end_shard}',
             'status': 'PENDING',
-            'serial': "<%s" % (timeutils.utcnow_ts() - self.max_prop_time)
+            'serial': '<%s' % (timeutils.utcnow_ts() - self.max_prop_time)
         }
 
         stale_zones = self.storage.find_zones(self.context, stale_criterion)
@@ -849,7 +873,7 @@ class ExportZone(base.Task):
     """
 
     def __init__(self, executor, context, zone, export):
-        super(ExportZone, self).__init__(executor)
+        super().__init__(executor)
         self.context = context
         self.zone = zone
         self.export = export
