@@ -89,7 +89,6 @@ run_process "designate-api" "$(which uwsgi) --procname-prefix designate-api --in
 run_process designate-producer "$DESIGNATE_BIN_DIR/designate-producer --config-file $DESIGNATE_CONF"
 run_process designate-worker "$DESIGNATE_BIN_DIR/designate-worker --config-file $DESIGNATE_CONF"
 run_process designate-mdns "$DESIGNATE_BIN_DIR/designate-mdns --config-file $DESIGNATE_CONF"
-run_process designate-agent "$DESIGNATE_BIN_DIR/designate-agent --config-file $DESIGNATE_CONF"
 run_process designate-sink "$DESIGNATE_BIN_DIR/designate-sink --config-file $DESIGNATE_CONF"
 restart_apache_server
 
@@ -103,7 +102,7 @@ if ! timeout $SERVICE_TIMEOUT sh -c "while ! wget --no-proxy -q -O- $DESIGNATE_S
 fi
 
 # Don't succeed unless the service come up
-ensure_services_started designate-api designate-central designate-producer designate-worker designate-mdns designate-agent designate-sink
+ensure_services_started designate-api designate-central designate-producer designate-worker designate-mdns designate-sink
 
 set +o xtrace
 echo "*********************************************************************"
